import data, gamestate, lawn
import math, pygame

def startup():
  pygame.init()
  gamestate.screen = pygame.display.set_mode(gamestate.sdim)

# Return a semi-transparent shadow ellipse
def shadow(dim, alpha = 80):
  s = pygame.Surface(dim).convert_alpha()
  s.fill((0,0,0,0))
  pygame.draw.ellipse(s, (0,0,0,alpha), s.get_rect())
  return s

def leapto(p0, p1, speed, maxjump):
  x0, y0 = p0
  x1, y1 = p1
  dx, dy = x1 - x0, y1 - y0
  d = math.sqrt(dx ** 2 + dy ** 2)
  n = int(d / speed) + 1
  njump = int(maxjump)
  c = []
  r0, r1 = 0, maxjump
  for a in [float(x)/n for x in range(1, n)]:
    x = x0 + dx * a
    y = y0 + dy * a
    if d*a > r1: r0, r1 = r1, r1 + maxjump
    if r1 > d: r1 = d
    z = (d*a - r0) * (r1 - d*a) * 3
    c.append((x,y,z))
  c.append((x1, y1, 0))
  return c

def main():
  startup()
  lawnframe = lawn.makelawn(gamestate.lawndim, (100,50,0), (0,255,0), 360)
  acorn = [data.loadimg("acorn%s.png" % j) for j in range(12)]
  s = shadow((48, 24))
  x,y,z = 0,0,0
  clock = pygame.time.Clock()
  done = False
  ps = []
  ctheta = 0
  theta = 0
  while not done:
    clock.tick(30)
    theta += 1
    C, S = math.cos(math.radians(theta)), math.sin(math.radians(theta))
    for event in pygame.event.get():
      if event.type == pygame.KEYDOWN and event.key == pygame.K_ESCAPE:
        done = True
      if event.type == pygame.KEYDOWN and event.key == pygame.K_SPACE:
        pygame.image.save(gamestate.screen, data.filepath("screencap.png"))
      if event.type == pygame.MOUSEBUTTONDOWN:
        fx, fy = event.pos
        fx, fy = (fx-300.)/300., (fy-250.)/150.
        if fx**2 + fy**2 < 1. and len(ps) == 0:
          fx, fy = C*fx - S*fy, S*fx + C*fy
          ps.extend(leapto((x,y), (fx, fy), 0.05, 0.3))
          ctheta = math.degrees(math.atan2(x-fx, fy-y))

    gamestate.screen.fill((0,64,0))
    gamestate.screen.blit(lawnframe[int(theta/1.)%360], (0,100))

    if len(ps):
      x,y,z = ps.pop(0)
    nx, ny = C*x + S*y, -S*x + C*y
    px, py, pz = nx*300+300, ny*150+250, z*220
    r = s.get_rect()
    r.center = px, py
    gamestate.screen.blit(s, r)
    jcorn = int((-theta + ctheta) * 12. / 360 + 0.5)
    r = acorn[jcorn % 12].get_rect()
    r.midbottom = px, py - pz
    gamestate.screen.blit(acorn[jcorn % 12], r)
    pygame.display.flip()

